<?php

if (!defined('SMF'))
	die('Hacking attempt...');
	
/*

	Blog Community 2.0.2 Beta
	
	Blog Community was developed by Charles Hill for use in conjunction with Simple Machines Forum.  The 
	code of Blog Community is not to be redistributed or used for any purpose other than what is intended 
	without express written permission from the developer.  All rights are reserved by the developer.
	
	This software is distributed in the hope that it is and will be useful, but WITHOUT ANY WARRANTIES; without even 
	any implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	
*/




// this funciton is for loading the blog settings arrays in the blog control panel or when viewing a single blog
function prepareDefaultBlogSettings($memID = null)
{
	global $context, $txt, $db_prefix, $user_info, $modSettings, $settings, $scripturl, $blog, $sourcedir;
	
	// Load the language files
	if (loadlanguage('Blog') == false)
		loadLanguage('Blog','english');
	
	/* 
		Here's how it works:  
		'settingName' => array(
			'value' => this setting's default value (required), 
			'type' => check/int/text (required),
			'required' => 1 means the field is required (optional),
			'useBoardOption' => name of the $boardOptions[variable] to set equal to this value when 
				saving settings (required only if required by modifyBoards()),
			'custom' => hidden/select/multiCheck/radio (optional),
			'options' => array of options for a setting that uses select or radio (optional),
			'alwaysInclude' => array of values to always include in this value when saving (optional),
			'headerAbove' => text string to display as a header above this setting (optional),
			'instructions' => text string to display as normal text above this setting (optional),
			'permission' => user must have this permission to do anything with this setting (optional),
			'subtext' => appears below the primary text for the form field (optional),
			'helptext' => creates (?) link next to primary text... text here is displayed in a pop-up window once the user clicks on the link (optional),
			'mustReturnTrue' => must return true for this setting to be available (optional),
			'require_url_verification' => true to require verification of a URL via get_headers() (optional),
			'base_url_for_verification' => base url to add BEFORE the value entered by the user and then URL is verified via get_headers() (optional),
		),
		
		NOTE:
		- When adding settings, you'll need to add a $txt variable with the EXACT name as 
		the setting you're adding to the Blog language file.... example:  for a new setting 
		called 'newSetting', you'd need to add $txt['newSetting'] in the blog language file.
	*/
	
	$context['blog']['defaultSettings'] = array(
		'blogName' => array(
			'value' => '',
			'type' => 'text',
			'required' => 1,
			'useBoardOption' => 'board_name',
		),
		'blogDescription' => array(
			'value' => '',
			'type' => 'text',
			'custom' => 'textarea',
			'useBoardOption' => 'board_description',
		),
		'hideBlog' => array(
			'value' => 0,
			'type' => 'check',
		),
		'meta_keywords' => array(
			'value' => '',
			'type' => 'text',
			'custom' => 'textarea',
			'helptext' => $txt['helptext_meta_keywords'],
		),
		'show_prev_next' => array(
			'value' => 0,
			'type' => 'check',
		),
		'show_go_to_top' => array(
			'value' => 0,
			'type' => 'check',
		),
		'hide_poll_articles' => array(
			'value' => 1,
			'type' => 'check',
		),
		'pseudoIndependent' => array(
			'value' => 0,
			'type' => 'check',
			'permission' => 'pseudo_independent_blog',
			'subtext' => $txt['sub_pseudoInd'],
		),
		'blogTheme' => array(
			'value' => 'default',
			'type' => 'text',
			'custom' => 'select',
			'options' => array(
				'default' => $txt['b8'],
			),
			'permission' => 'pseudo_independent_blog',
			'instructions' => $txt['subtext_blogTheme'],
		),
		'blog_page_width' => array(
			'type' => 'text',
			'value' => $modSettings['blog_index_width'],
			'subtext' => $txt['subtext_blog_index_width'],
			'permission' => 'pseudo_independent_blog',
		),
		'blog_page_alignment' => array(
			'type' => 'text',
			'custom' => 'select',
			'value' => 'center',
			'options' => array(
				'center' => $txt['b82'],
				'left' => $txt['b10'],
				'right' => $txt['b9'],
			),
			'permission' => 'pseudo_independent_blog',
		),
		'max_topics_on_blog' => array(
			'value' => 5,
			'type' => 'int',
			'headerAbove' => $txt['topics_and_comments'],
			'subtext' => $txt['zero_for_no_limit'],
		),
		'max_length_topics' => array(
			'value' => 2400,
			'type' => 'int',
			'subtext' => $txt['zero_for_no_limit'],
		),
		'show_last_edit_topics' => array(
			'value' => 1,
			'type' => 'check',
		),
		'show_tags' => array(
			'value' => 1,
			'type' => 'check',
			'subtext' => $txt['not_effect_tagWin'],
		),
		'show_categories' => array(
			'value' => 1,
			'type' => 'check',
			'subtext' => $txt['not_effect_catWin'],
		),
		'hide_comments' => array(
			'value' => 0,
			'type' => 'check',
		),
		'display_comments_blog' => array(
			'value' => 1,
			'type' => 'check',
		),
		'comments_require_approval' => array(
			'value' => 0,
			'type' => 'check',
			'helptext' => $txt['help_comments_approval'],
		),
		'max_comments_per_topic' => array(
			'value' => 3,
			'type' => 'int',
			'subtext' => $txt['zero_for_no_limit'],
		),
		'max_length_comments' => array(
			'value' => 500,
			'type' => 'int',
			'subtext' => $txt['zero_for_no_limit'],
		),
		'show_last_edit_comments' => array(
			'value' => 1,
			'type' => 'check',
		),
		'show_socialbookmarks_topics' => array(
			'value' => 1,
			'type' => 'check',
			'subtext' => $txt['eg_digg_stumble'],
		),
		'socialbookmarks_multicheck' => array(
			'value' => 'digg,delicious,furl,stumbleupon,technorati',
			'type' => 'text',
			'custom' => 'multiCheck',
			'needsExplode' => true,
			'instructions' => $txt['socialbookmarks_multicheck_instructions'],
			'options' => array(
				'digg' => 'Digg',
				'delicious' => 'Del.icio.us',
				'furl' => 'Furl',
				'stumbleupon' => 'Stumble Upon',
				'technorati' => 'Technorati',
				'reddit' => 'Reddit',
				'blinklist' => 'BlinkList',
				'google' => 'Google',
				'twitter' => 'Twitter',
				'facebook' => 'Facebook',
				'magnolia' => 'Mag.nolia',
				'myweb' => 'Yahoo! MyWeb',
				'windowslive' => 'Windows Live',
			),
			'headerAbove' => $txt['social_bookmarks'],
		),
		'allowedGroups' => array(
			'type' => 'text',
			'value' => isset($modSettings['defaultAllowedGroups']) ? $modSettings['defaultAllowedGroups'] : '-1,0,2',
			'custom' => 'multiCheck',
			'alwaysInclude' => array('2'),
			'options' => array(),
			'instructions' => $txt['blog_select_allowedGroups'],
			'headerAbove' => $txt['access_restrictions'],
			'permission' => 'blog_restrict_access',
			'useBoardOption' => 'access_groups',
		),
		'myBlogLogSiteID' => array(
			'value' => '',
			'type' => 'text',
			'headerAbove' => $txt['b33'],
			'subtext' => $txt['required_b'],
			'require_url_verification' => true,
			'base_url_for_verification' => 'http://www.mybloglog.com/buzz/community/',
			'custom' => 'require_url_verification',
			'mustReturnTrue' => !empty($modSetting['allowMyBlogLog']),
		),
		'myBlogLogButton' => array(
			'value' => 0,
			'type' => 'int',
			'custom' => 'radio',
			'options' => array(
				$txt['b11'],
				'<img src="http://www.mybloglog.com/buzz/images/buttons/btn_c11.png" style="border: 0px none;" alt="'. $txt['b34'] .'" />',
				'<img src="http://www.mybloglog.com/buzz/images/buttons/btn_c12.png" style="border: 0px none;" alt="'. $txt['b34'] .'" />',
				'<img src="http://www.mybloglog.com/buzz/images/buttons/btn_c13.png" style="border: 0px none;" alt="'. $txt['b34'] .'" />',
				'<img src="http://www.mybloglog.com/buzz/images/buttons/btn_c14.png" style="border: 0px none;" alt="'. $txt['b34'] .'" />',
				'<img src="http://www.mybloglog.com/buzz/images/buttons/btn_c21.png" style="border: 0px none;" alt="'. $txt['b34'] .'" />',
				'<img src="http://www.mybloglog.com/buzz/images/buttons/btn_c22.png" style="border: 0px none;" alt="'. $txt['b34'] .'" />',
				'<img src="http://www.mybloglog.com/buzz/images/buttons/btn_c23.png" style="border: 0px none;" alt="'. $txt['b34'] .'" />',
				'<img src="http://www.mybloglog.com/buzz/images/buttons/btn_c24.png" style="border: 0px none;" alt="'. $txt['b34'] .'" />',
				'<img src="http://www.mybloglog.com/buzz/images/buttons/btn_c31.png" style="border: 0px none;" alt="'. $txt['b34'] .'" />',
				'<img src="http://www.mybloglog.com/buzz/images/buttons/btn_c32.png" style="border: 0px none;" alt="'. $txt['b34'] .'" />',
				'<img src="http://www.mybloglog.com/buzz/images/buttons/btn_c33.png" style="border: 0px none;" alt="'. $txt['b34'] .'" />',
				'<img src="http://www.mybloglog.com/buzz/images/buttons/btn_c34.png" style="border: 0px none;" alt="'. $txt['b34'] .'" />',
				'<img src="http://www.mybloglog.com/buzz/images/buttons/btn_c22_l.png" style="border: 0px none;" alt="'. $txt['b34'] .'" />',
			),
			'mustReturnTrue' => !empty($modSettings['allowMyBlogLog']),
		),
		'enableMBLStatTracking' => array(
			'value' => 0,
			'type' => 'check',
			'mustReturnTrue' => !empty($modSettings['allowMyBlogLog']),
		),
		'blogCatalogURL' => array(
			'value' => '',
			'type' => 'text',
			'subtext' => $txt['required_b'] . ' ' . $txt['b7'] . ' ' . $txt['b12'] . ' 1',
			'require_url_verification' => true,
			'custom' => 'require_url_verification',
			'mustReturnTrue' => !empty($modSettings['allowBlogCatalog']),
		),
		'blogCatalogID' => array(
			'value' => '',
			'type' => 'text',
			'subtext' => $txt['required_b'] . ' ' . $txt['b7'] . ' ' . $txt['b12a'] . ' 2 ' . $txt['b37'] . ' 3',
			'mustReturnTrue' => !empty($modSettings['allowBlogCatalog']),
		),
		'blogCatalogButton' => array(
			'value' => 0,
			'type' => 'int',
			'custom' => 'radio',
			'options' => array(
				$txt['b11'],
				'<img src="http://www.blogcatalog.com/images/buttons/blogcatalog5.gif" alt="'. $txt['b12'] .' 1" />',
				'<img src="'. $settings['default_theme_url'] .'/images/blogCatalog_button2.gif" alt="'. $txt['b12'] .' 2" />',
				'<img src="'. $settings['default_theme_url'] .'/images/blogCatalog_button3.gif" alt="'. $txt['b12'] .' 3" />',
			),
			'mustReturnTrue' => !empty($modSettings['allowBlogCatalog']),
		),
		'hide_side_windows' => array(
			'value' => 0,
			'type' => 'check',
			'headerAbove' => $txt['side_windows'],
		),
		'justifySideWindows' => array(
			'value' => 0,
			'type' => 'int',
			'custom' => 'select',
			'options' => array(
				$txt['b9'],
				$txt['b10'],
			),
		),
		'enableRecentEntries' => array(
			'value' => 1,
			'type' => 'check',
		),
		'num_recent_entries' => array(
			'value' => 7,
			'type' => 'int',
			'subtext' => $txt['zero_for_no_limit'],
		),
		'enableCategoryList' => array(
			'value' => 0,
			'type' => 'check',
		),
		'enableArchives' => array(
			'value' => 1,
			'type' => 'check',
		),
		'enableLinksWindow' => array(
			'value' => 0,
			'type' => 'check',
		),
		'enableFriendsOfWindow' => array(
			'value' => 0,
			'type' => 'check',
		),
		'enableStatsWindow' => array(
			'value' => 0,
			'type' => 'check',
		),
		'enableTagsWindow' => array(
			'value' => 0,
			'type' => 'check',
		),
		'enableWhoViewingWindow' => array(
			'value' => 0,
			'type' => 'check',
		),
		'useAvatarsForWhoViewing' => array(
			'value' => 1,
			'type' => 'check',
		),
		'enableMostCommentedWindow' => array(
			'value' => 0,
			'type' => 'check',
		),
		'limit_most_commented' => array(
			'value' => 5,
			'type' => 'int',
			'subtext' => $txt['zero_for_no_limit'],
		),
		'enableRecentCommentsWindow' => array(
			'value' => 0,
			'type' => 'check',
		),
		'limit_recent_comments' => array(
			'value' => 5,
			'type' => 'int',
			'subtext' => $txt['zero_for_no_limit'],
		),
		'enablePollsWindow' => array(
			'value' => 0,
			'type' => 'check',
		),
		'limit_num_polls' => array(
			'value' => 2,
			'type' => 'int',
			'subtext' => $txt['zero_for_no_limit'],
		),
		'recentWindowOrder' => array(
			'value' => 1,
			'type' => 'int',
			'custom' => 'hidden',
		),
		'categoriesWindowOrder' => array(
			'value' => 2,
			'type' => 'int',
			'custom' => 'hidden',
		),
		'archivesWindowOrder' => array(
			'value' => 3,
			'type' => 'int',
			'custom' => 'hidden',
		),
		'linksWindowOrder' => array(
			'value' => 4,
			'type' => 'int',
			'custom' => 'hidden',
		),
		'friendsWindowOrder' => array(
			'value' => 5,
			'type' => 'int',
			'custom' => 'hidden',
		),
		'tagsWindowOrder' => array(
			'value' => 6,
			'type' => 'int',
			'custom' => 'hidden',
		),
		'statsWindowOrder' => array(
			'value' => 7,
			'type' => 'int',
			'custom' => 'hidden',
		),
		'whoViewingWindowOrder' => array(
			'value' => 8,
			'type' => 'int',
			'custom' => 'hidden',
		),
		'mostCommentedWindowOrder' => array(
			'value' => 9,
			'type' => 'int',
			'custom' => 'hidden',
		),
		'recentCommentsWindowOrder' => array(
			'value' => 10,
			'type' => 'int',
			'custom' => 'hidden',
		),
		'pollsWindowOrder' => array(
			'value' => 11,
			'type' => 'int',
			'custom' => 'hidden',
		),
		'usersAllowedToBlog' => array(
			'value' => '',
			'type' => 'text',
			'custom' => 'hidden',
			'needsExplode' => true,
		),
		'groupsAllowedToBlog' => array(
			'value' => '',
			'type' => 'text',
			'custom' => 'hidden',
			'needsExplode' => true,
		),
	);
	
	if (!empty($context['viewingControlPanel']))
	{
		$context['blog']['settings']['hide_poll_articles']['mustReturnTrue'] = $modSettings['pollMode'] == '1' && $context['can_poll_view'] && $context['can_poll_add'];
		$context['blog']['settings']['limit_num_polls']['mustReturnTrue'] = $modSettings['pollMode'] == '1' && $context['can_poll_view'] && $context['can_poll_add'];
		$context['blog']['settings']['enablePollsWindow']['mustReturnTrue'] = $modSettings['pollMode'] == '1' && $context['can_poll_view'] && $context['can_poll_add'];
	}
	
	// populate the options array of allowedGroups
	if (empty($context['viewingBlogHelp']) && $context['viewingControlPanel'] && ($context['can_blog_restrict_access'] || $context['can_blog_set_posting_restrictions']))
		if (!empty($context['memGroups']))
			foreach ($context['memGroups'] as $id => $name)
				$context['blog']['defaultSettings']['allowedGroups']['options'][$id] = $name;

	// simple array of side windows
	$context['blog']['sideWindows'] = array(
		'recent',
		'categories',
		'archives',
		'links',
		'friends',
		'stats',
		'tags',
		'whoViewing',
		'mostCommented',
		'recentComments',
		'polls',
	);
	
	if (!empty($blog))
	{
		// only use page index if we are viewing the blog control panel
		if (!empty($context['viewingControlPanel']) && !empty($memID) && !empty($_REQUEST['sa']) && $_REQUEST['sa'] == 'customWindows')
		{
			// count number of custom windows
			$request = db_query("
				SELECT COUNT(*) AS numCustomWindows 
				FROM {$db_prefix}blog_custom_windows 
				WHERE boardID = $blog", __FILE__, __LINE__);
				
			if (mysql_num_rows($request) > 0)
				$row = mysql_fetch_assoc($request);
				
			$maxindex = 15;
			// show all if that's what they want :)
			if (isset($_REQUEST['all']))
				$maxindex = 99999;
			$start = (int) $_REQUEST['start'];
			$numCustomWindows = !empty($row['numCustomWindows']) ? $row['numCustomWindows'] : 0;
			
			$context['page_index'] = constructPageIndex($scripturl . '?action=blogControlPanel;u='. $memID .';blog='. $blog .';sa='. $_REQUEST['sa'] .';start=%d', $_REQUEST['start'], $numCustomWindows, $maxindex, true);
	
			$context['show_page_index'] = !empty($numCustomWindows) && $numCustomWindows > $maxindex;
		}
	
		$request = db_query("
			SELECT windowID, title, content 
			FROM {$db_prefix}blog_custom_windows 
			WHERE boardID = $blog" . (!empty($context['viewingControlPanel']) && !empty($memID) && !empty($_REQUEST['sa']) && $_REQUEST['sa'] == 'customWindows' ? "
			LIMIT $start, $maxindex" : ''), __FILE__, __LINE__);
			
		$customWindowNumber = 0;
		$numBasicSideWindows = count($context['blog']['sideWindows']);
		
		// build custom windows array
		$context['customWindows'] = array();
		while ($row = mysql_fetch_assoc($request))
		{
			$customWindowNumber = $customWindowNumber + 1;
			
			$context['customWindows'][$row['windowID']] = array(
				'id' => $row['windowID'],
				'title' => $row['title'],
				'content' => un_htmlspecialchars(stripslashes($row['content'])),
				'preview_link' => '<a href="'. $scripturl .'?action=previewCustomWindow;blog='. $blog .';window='. $row['windowID'] .'" onclick="return reqWin(this.href);" rel="nofollow"><img src="'. $settings['default_theme_url'] .'/images/icons/preview_icon_16.gif" alt="'. $txt[507] .'" title="'. $txt[507] .'" /></a>',
				'name' => 'Custom ' . $customWindowNumber,
				'var_name' => 'custom' . $customWindowNumber,
				'custom_num' => $customWindowNumber,
			);
			
			$txt['enableCustom' . $customWindowNumber . 'Window'] = $txt['enableCustomWin'] . ' ' . $customWindowNumber;
			$txt['custom' . $customWindowNumber . 'WindowOrder'] = $txt['customWin'] . ' ' . $customWindowNumber;
			$context['blog']['sideWindows'][] = 'custom' . $customWindowNumber;
			$context['blog']['defaultSettings']['custom' . $customWindowNumber . 'WindowOrder'] = array(
				'value' => $numBasicSideWindows + $customWindowNumber,
				'type' => 'int',
				'custom' => 'hidden',
			);
			$context['blog']['defaultSettings']['enableCustom' . $customWindowNumber . 'Window'] = array(
				'value' => '0',
				'type' => 'check',
			);
		}
		
		if (!empty($context['customWindows']))			
			$context['customWindows'][0] = array(
				'remove_link' => true,
				'edit_link' => true,
				'preview_link' => true,
				'move_link' => false,
			);
			
		mysql_free_result($request);
	}
	
	if ($user_info['is_admin'] && $context['viewingControlPanel'])
	{
		// set up the admin-only blog settings array
		$context['blog']['admin_settings'] = array(
			'blogMode' => array(
				'type' => 'int',
				'value' => 0,
				'custom' => 'select',
				'options' => array(
					$txt['blogMode0'],
					$txt['blogMode1'],
					$txt['blogMode2'],
					$txt['blogMode3'],
				),
				'helptext' => $txt['help_blogMode'],
			),
			'blogBoard' => array(
				'type' => 'int',
				'value' => 0,
				'custom' => 'select',
				'options' => array(),
				'helptext' => $txt['help_blogBoard'],
			),
			'excludeBlogsForumTotals' => array(
				'type' => 'check',
				'value' => 1,
			),
			'hideBlogBoards' => array(
				'type' => 'check',
				'value' => 1,
			),
			'hideBlogPostsFromForumRecentPosts' => array(
				'type' => 'check',
				'value' => 1,
				'subtext' => $txt['use_maintenance_after'],
			),
			'max_num_blogs' => array(
				'type' => 'int',
				'value' => 5,
				'subtext' => $txt['subtext_max_num_blogs'],
			),
			'allowBlogCatalog' => array(
				'type' => 'check',
				'value' => 0,
			),
			'allowMyBlogLog' => array(
				'type' => 'check',
				'value' => 0,
			),
			'toggle_all_layerless' => array(
				'type' => 'check',
				'value' => 0,
				'subtext' => $txt['subtext_all_layerless'],
			),
			'hide_portal_blocks' => array(
				'type' => 'check',
				'value' => 0,
			),
			'maxIndexArticleList' => array(
				'type' => 'int',
				'value' => 20,
				'subtext' => $txt['zero_for_no_limit'],
			),
			'maxIndexCommentList' => array(
				'type' => 'int',
				'value' => 10,
				'subtext' => $txt['zero_for_no_limit'] . '<br />' . $txt['sub_maxIndCommentList'],
			),
			'sortBlogIndexByViews' => array(
				'type' => 'check',
				'value' => 1,
				'headerAbove' => $txt['blog_index'],
			),
			'showAvatarsOnBlogIndex' => array(
				'type' => 'check',
				'value' => 1,
			),
			'showRSSFeedsOnBlogIndex' => array(
				'type' => 'check',
				'value' => 0,
				'subtext' => $txt['subtext_showRSSFeedsOnBlogIndex'],
			),
			'maxIndexOnBlogIndex' => array(
				'type' => 'int',
				'value' => 20,
				'subtext' => $txt['zero_for_no_limit'],
			),
			'blog_index_side_bar' => array(
				'type' => 'int',
				'value' => 0,
				'custom' => 'select',
				'options' => array(
					$txt['b84'],
					$txt['b10'],
					$txt['b9'],
				),
			),
			'enableGlobalTagsWindow' => array(
				'type' => 'check',
				'value' => 0,
			),
			'enableGlobalMostRecentWindow' => array(
				'type' => 'check',
				'value' => 0,
			),
			'blog_index_without_layers' => array(
				'type' => 'check',
				'value' => 0,
			),
			'blog_index_width' => array(
				'type' => 'text',
				'value' => '65%',
				'subtext' => $txt['subtext_blog_index_width'],
				'instructions' => $txt['subtext_blog_index_nolayers'],
			),
			'blog_index_alignment' => array(
				'type' => 'text',
				'custom' => 'select',
				'value' => 'center',
				'options' => array(
					'center' => $txt['b82'],
					'left' => $txt['b10'],
					'right' => $txt['b9'],
				),
			),
			'category_for_blogs' => array(
				'type' => 'int',
				'value' => 0,
				'custom' => 'select',
				'options' => array(),
				'headerAbove' => $txt['default_settings_for_new_blogs'],
			),
			'default_meta_keywords' => array(
				'value' => '',
				'type' => 'text',
				'custom' => 'textarea',
				'helptext' => $txt['helptext_meta_keywords'],
				'subtext' => $txt['subtext_default_meta'],
			),
			'defaultAllowedGroups' => array(
				'type' => 'text',
				'value' => '-1,0,2',
				'custom' => 'multiCheck',
				'alwaysInclude' => array('2'),
				'options' => array(),
				'instructions' => $txt['default_selectAllowedGroups'],
			),
			'disable_guest_captcha' => array(
				'type' => 'check',
				'value' => 0,
				'headerAbove' => $txt['captcha'],
			),
			'captcha_blog_only' => array(
				'type' => 'check',
				'value' => 1,
			),
		);
	}
			
	// plug-in slot #6
	if (!empty($context['blog']['plugin_slots'][6]))
		if (file_exists($sourcedir . '/BlogPlugins.php'))
		{
			require_once($sourcedir . '/BlogPlugins.php');
			if (function_exists('blogPluginSlot6'))
				blogPluginSlot6();
		}
}


?>